@@ -177,10 +177,10 @@ _partition_warn_busy (PedPartition* part)
 			_("Partition %s is being used.  You must unmount it "
 			  "before you modify it."),
 			path);
-		ped_free (path);
+		PED_FREE (path);
 		return 0;
 	}
-	ped_free (path);
+	PED_FREE (path);
 	return 1;
 }
 
@@ -621,13 +621,13 @@ query_part_position(const char* prompt, const void* context, PartPos *pos,
 				} else {
 					strncpy(buf,_("Size"),SMALLBUF);
 				}
-				if (temp) ped_free(temp);
-				if (temp2) ped_free(temp2);
+				if (temp) PED_FREE(temp);
+				if (temp2) PED_FREE(temp2);
 				def_str = ped_unit_format(dev,length);
 				if (def_str) temp = strdup(def_str);
 				if (!uiquery->getstring(buf, &temp, NULL, NULL, 1)) {
-					if (temp) ped_free(temp);
-					if (def_str) ped_free(def_str);
+					if (temp) PED_FREE(temp);
+					if (def_str) PED_FREE(def_str);
 					return 0;
 				}
 
@@ -649,8 +649,8 @@ query_part_position(const char* prompt, const void* context, PartPos *pos,
 						length = min_len;
 					}
 				}
-				if (temp) ped_free(temp);
-				if (def_str) ped_free(def_str);
+				if (temp) PED_FREE(temp);
+				if (def_str) PED_FREE(def_str);
 			}
 			/* If we place it at the beginning, we will have range
 			   with the end sector and conversly if we place it at
@@ -998,16 +998,16 @@ get_sector (const char* prompt, PedDevice* dev, SectPos *value,
 		if (!(opts & NO_RANGE)) {
 			if (!value->range)
 				value->range = ped_geometry_new (dev,value->sector,1);
-			ped_free (def_str);
-			ped_free (input);
+			PED_FREE (def_str);
+			PED_FREE (input);
 			return value->range != NULL;
 		}
-		ped_free (def_str);
-		ped_free(input);
+		PED_FREE (def_str);
+		PED_FREE(input);
 		return 1;
 	}
 
-	ped_free (def_str);
+	PED_FREE (def_str);
 	if (!input) {
 		value->sector = 0;
 		if (!(opts & NO_RANGE)) {
@@ -1049,7 +1049,7 @@ get_sector (const char* prompt, PedDevice* dev, SectPos *value,
 	} else {
 		valid = ped_unit_parse(input, dev, &(value->sector),
 		                                   &(value->range));
-		ped_free (input);
+		PED_FREE (input);
 	}
 	return valid;
 }
@@ -1564,13 +1564,13 @@ perform_mkpart (PedDisk* disk, PartPos *pos, PedPartitionType part_type,
                 ped_geometry_destroy (pos->end.range);
 
         if (start_usr != NULL)
-                ped_free (start_usr);
+                PED_FREE (start_usr);
         if (end_usr != NULL)
-                ped_free (end_usr);
+                PED_FREE (end_usr);
         if (start_sol != NULL)
-                ped_free (start_sol);
+                PED_FREE (start_sol);
         if (end_sol != NULL)
-                ped_free (end_sol);
+                PED_FREE (end_sol);
 	if (newpart) *newpart = part;
         return 1;
 
@@ -1592,13 +1592,13 @@ error:
                 ped_geometry_destroy (pos->end.range);
 
         if (start_usr != NULL)
-                ped_free (start_usr);
+                PED_FREE (start_usr);
         if (end_usr != NULL)
-                ped_free (end_usr);
+                PED_FREE (end_usr);
         if (start_sol != NULL)
-                ped_free (start_sol);
+                PED_FREE (start_sol);
         if (end_sol != NULL)
-                ped_free (end_sol);
+                PED_FREE (end_sol);
 
         return 0;
 }
@@ -1843,8 +1843,8 @@ _rescue_add_partition (PedPartition* part)
                 fs_type->name, ped_partition_type_get_name (part->type),
                 found_start, found_end);
         ped_geometry_destroy (probed);
-        ped_free (found_start);
-        ped_free (found_end);
+        PED_FREE (found_start);
+        PED_FREE (found_end);
 
         switch (ex_opt) {
                 case PED_EXCEPTION_CANCEL: return -1;
@@ -2367,7 +2367,7 @@ check_partition_consistency (PedPartition *part)
 	part_chs = ped_unit_format_custom(part->disk->dev,part->geom.end,
 	                                  PED_UNIT_CHS);
 	sscanf(part_chs, "%d,%d,%d", &end_cyl, &end_head, &end_sector);
-	ped_free(part_chs);
+	PED_FREE(part_chs);
 
 	/* If, for example, this is a msdos logical partition, it has a
            tail of one sector, specifying the next partition. */
